<?php
// $Id: rawlog.admin.inc,v 1.1.2.2 2010/03/14 23:05:58 vitoa Exp $

/**
 * Rawlog module settings.
 */
function rawlog_admin_settings() {
  // Use javascript for some added usability on admin form.
  $files_folder = '<script type="text/javascript">var files_folder = "'. addslashes(file_directory_path()) .'/";</script>';
  
  drupal_add_js(drupal_get_path('module', 'rawlog') .'/rawlog.js');

  $form['#prefix'] .= $files_folder;
  
  // Configuration option for the log file name.
  $form['rawlog_logfile'] = array(
    '#type' => 'textfield', 
    '#title' => t('Log file name'), 
    '#default_value' => variable_get('rawlog_logfile', drupal_get_path('module', 'rawlog') .'/rawlog.log'), 
    '#description' => t('Please specify a path to your log file.<br />Web server must have write permission to the file.<br />If file not exists, it will be created.'),
  );

  // Configuration option for placing the log file to the files folder.
  $form['rawlog_place_to_files'] = array(
    '#type' => 'checkbox',
    '#title' => t('Place to the files folder'),
    '#description' => t('Place the log file to the files folder.<br />Use with care - will change your previous entered log file path leaving the file name.'),
    '#default_value' => variable_get('rawlog_place_to_files', FALSE),
  );
  
  // System events severity list.
  $severity_list = rawlog_severity_list();
  $form['rawlog_severity_level'] = array(
    '#type' => 'select',
    '#title' => t('Severity level'),
    '#description' => t('Minimum severity level for system events to include in the log.'),
    '#options' => $severity_list,
    '#default_value' => variable_get('rawlog_severity_level', 4),
  );

  $form['rawlog_tag_settings'] = array(
    '#type' => 'fieldset', 
    '#title' => t('Tagging'),
    '#description' => t('You may configure additional settings to include events having a corresponding tags (keywords) here.'),
    '#collapsible' => TRUE, 
    '#collapsed' => TRUE,
  );

  $rawlog_enable_tags = variable_get('rawlog_enable_tags', FALSE);
  
  $form['rawlog_tag_settings']['rawlog_enable_tags'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable tags'),
    '#default_value' => $rawlog_enable_tags,
    '#description' => t('Enable filtering of events based on a corresponding tags (keywords).'),
    '#weight' => 1,
  );

  $form['rawlog_tag_settings']['rawlog_tags'] = array(
    '#type' => 'textfield',
    '#title' => t('Tags'),
    '#description' => t('Please list the comma-separated tags (keywords) here.'),
    '#default_value' => variable_get('rawlog_tags', ''),
    '#weight' => 2,
    '#disabled' => !$rawlog_enable_tags,
  );

  $full_form = system_settings_form($form);
  $full_form['#submit'][] = 'rawlog_admin_settings_submit';
  
  return $full_form;
}

/**
 * Attempts to create a log file when the admin settings form is submitted.
 */
function rawlog_admin_settings_submit($form, &$form_state) {
  // Attempt to create the log file if not exists.
  if (isset($form_state['values']['rawlog_logfile'])) {
    $logfile = $form_state['values']['rawlog_logfile'];
  }
  if ($logfile && !file_exists($logfile)) {
    rawlog_create_logfile($logfile);
  }
}
